SystemOrganization addCategory: #ConfigurationOfOrca!

Object subclass: #ConfigurationOfOrca
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfOrca'!

!ConfigurationOfOrca class methodsFor: 'private' stamp: 'robi 4/11/2011 12:59'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfOrca class methodsFor: 'private' stamp: 'robi 4/11/2011 13:01'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfOrca class methodsFor: 'metacello tool support' stamp: 'robi 4/11/2011 13:01'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfOrca class methodsFor: 'metacello tool support' stamp: 'robi 4/11/2011 13:01'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfOrca class methodsFor: 'loading' stamp: 'LT 4/15/2011 13:31:23.31'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfOrca class methodsFor: 'metacello tool support' stamp: 'robi 4/11/2011 13:01'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfOrca class methodsFor: 'accessing' stamp: 'robi 4/11/2011 13:02'!
project

	^self new project! !

!ConfigurationOfOrca class methodsFor: 'unloading Metacello' stamp: 'robi 4/11/2011 13:01'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfOrca methodsFor: 'baselines' stamp: 'ag 4/26/2011 11:52'!
baseline100: spec
	<version: '1.0-baseline'>

	spec for: #common do: [
		spec 
			blessing: #baseline;
			repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/bp2010h1';
			postLoadDoIt: #setupOrca.
				
		spec package: 'Sport' with: [spec repository: 'http://www.squeaksource.com/SPort' ].
		spec package: 'JSON' with: [spec repository: 'http://www.squeaksource.com/JSON' ].
		spec package: 'Swazoo' with: [ spec repository: 'http://www.squeaksource.com/Swazoo'. ].
		spec package: 'Cryptography' with: [ spec repository: 'http://www.squeaksource.com/Cryptography'. ].
		spec package: 'VB-Regex' with: [ spec repository: 'http://www.squeaksource.com/Regex'. ].

		spec package: 'OMeta2-Preload' with: [ 
				spec repository: 'http://www.squeaksource.com/OMeta'.
				spec postLoadDoIt: #setupOMeta.
		].

		spec project: 'JavaScript-Core' with: 
		[spec 
			className: 'ConfigurationOfSeaside30';
			repository: 'http://www.squeaksource.com/MetacelloRepository'].

		spec project: 'Grease' with: [
			spec
				className: 'ConfigurationOfGrease';
				repository: 'http://www.squeaksource.com/MetacelloRepository'
		].
		
		spec package: 'Orca-Core' with: [
			spec requires: #('Grease' 'OMeta2-Preload' 'Sport' 'JSON' 'Swazoo' 'VB-Regex' 'Cryptography' 'JavaScript-Core').
		].

		spec package: 'Orca-Tests' with: [ spec requires: #('Orca-Core'). ].
		spec package: 'Orca-Widgets' with: [ spec requires: #('Orca-Core'). ].
		spec package: 'Orca-Examples' with: [ spec requires: #('Orca-Core' 'Orca-Widgets'). ].
		spec package: 'Orca-Tools' with: [ spec requires: #('Orca-Core'). ].

		spec group: 'default' with: #('Orca-Core' 'Orca-Tests' 'Orca-Widgets' 'Orca-Examples' 'Orca-Tools').
	].! !

!ConfigurationOfOrca methodsFor: 'accessing' stamp: 'robi 4/12/2011 15:47'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfOrca methodsFor: 'setup' stamp: 'LT 4/15/2011 16:08:22.926'!
setupDispatcher

	(Smalltalk at: #OrcaDispatcher) start.! !

!ConfigurationOfOrca methodsFor: 'setup' stamp: 'robi 4/13/2011 00:12'!
setupMimeDatabase

	(Smalltalk at: #MIMEDocument) resetMIMEdatabase.
! !

!ConfigurationOfOrca methodsFor: 'as yet unclassified' stamp: 'robi 4/13/2011 15:24'!
setupOMeta
	Gofer new
		squeaksource: 'OMeta';
		package: 'OMeta2-Postload';
		fetch.! !

!ConfigurationOfOrca methodsFor: 'setup' stamp: 'LT 4/15/2011 14:15:13.142'!
setupOrca

	self
		setupMimeDatabase;
		setupDispatcher.! !

!ConfigurationOfOrca methodsFor: 'versions' stamp: 'ag 4/26/2011 11:50'!
version100: spec 
	<version: '1.0' imports: #('1.0-baseline') >

	spec for: #common do: 
		[spec blessing: #stable.
		spec 	
			package: 'Swazoo' with: 'Swazoo-2.3beta2.2'
		].! !
